Get class

Constructors

Get()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentContext → dynamic
no setter
height double
no setter
getter/setter pair
width double
no setter

Static Methods

back() → dynamic
offAll(dynamic page) → dynamic
showDialog({required String title, required Widget content}) → dynamic
snackbar(String title, String message, {Color? backgroundColor, Color? colorText, EdgeInsets? margin}) → dynamic
to(Widget page) → dynamic